ESteamNotificationType

Enum ESteamNotificationType 

#[repr(i32)]
pub enum ESteamNotificationType {
Show 30 variants Invalid = 0, Test = 1, Gift = 2, Comment = 3, Item = 4, FriendInvite = 5, MajorSale = 6, PreloadAvailable = 7, Wishlist = 8, TradeOffer = 9, General = 10, HelpRequest = 11, AsyncGame = 12, ChatMsg = 13, ModeratorMsg = 14, ParentalFeatureAccessRequest = 15, FamilyInvite = 16, FamilyPurchaseRequest = 17, ParentalPlaytimeRequest = 18, FamilyPurchaseRequestResponse = 19, ParentalFeatureAccessResponse = 20, ParentalPlaytimeResponse = 21, RequestedGameAdded = 22, SendToPhone = 23, ClipDownloaded = 24, TwoFaPrompt = 25, MobileConfirmation = 26, PartnerEvent = 27, PlaytestInvite = 28, TradeReversal = 29,
}
Steam notification types

Variants



Invalid = 0



Test = 1



Gift = 2



Comment = 3



Item = 4



FriendInvite = 5



MajorSale = 6



PreloadAvailable = 7



Wishlist = 8



TradeOffer = 9



General = 10



HelpRequest = 11



AsyncGame = 12



ChatMsg = 13



ModeratorMsg = 14



ParentalFeatureAccessRequest = 15



FamilyInvite = 16



FamilyPurchaseRequest = 17



ParentalPlaytimeRequest = 18



FamilyPurchaseRequestResponse = 19



ParentalFeatureAccessResponse = 20



ParentalPlaytimeResponse = 21



RequestedGameAdded = 22



SendToPhone = 23



ClipDownloaded = 24



TwoFaPrompt = 25



MobileConfirmation = 26



PartnerEvent = 27



PlaytestInvite = 28



TradeReversal = 29

Implementations

Source

impl ESteamNotificationType

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of ESteamNotificationType.

pub fn from_i32(value: i32) -> Option<ESteamNotificationType>

👎Deprecated:

Use the TryFrom<i32> implementation instead

Converts an i32 to a ESteamNotificationType, or None if value is not a valid variant.