pub struct CAuthenticationUpdateAuthSessionWithSteamGuardCodeRequest {
pub client_id: Option<u64>,
pub steamid: Option<u64>,
pub code: Option<String>,
pub code_type: Option<i32>,
}Expand description
Update auth session with Steam Guard code request
Fields
client_id: Option<u64>steamid: Option<u64>code: Option<String>code_type: Option<i32>Implementations
Sourceimpl CAuthenticationUpdateAuthSessionWithSteamGuardCodeRequest
impl CAuthenticationUpdateAuthSessionWithSteamGuardCodeRequest
Sourcepub fn client_id(&self) -> u64
pub fn client_id(&self) -> u64
Returns the value of client_id, or the default value if client_id is unset.
Sourcepub fn steamid(&self) -> u64
pub fn steamid(&self) -> u64
Returns the value of steamid, or the default value if steamid is unset.
Sourcepub fn code_type(&self) -> EAuthSessionGuardType
pub fn code_type(&self) -> EAuthSessionGuardType
Returns the enum value of code_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_code_type(&mut self, value: EAuthSessionGuardType)
pub fn set_code_type(&mut self, value: EAuthSessionGuardType)
Sets code_type to the provided enum value.