pub struct RefreshTokenDescription {Show 13 fields
pub token_id: Option<u64>,
pub token_description: Option<String>,
pub time_updated: Option<u32>,
pub platform_type: Option<i32>,
pub logged_in: Option<bool>,
pub os_platform: Option<u32>,
pub auth_type: Option<u32>,
pub gaming_device_type: Option<u32>,
pub first_seen: Option<TokenUsageEvent>,
pub last_seen: Option<TokenUsageEvent>,
pub os_type: Option<i32>,
pub authentication_type: Option<i32>,
pub effective_token_state: Option<i32>,
}Expand description
Refresh token description
Fields
token_id: Option<u64>token_description: Option<String>time_updated: Option<u32>platform_type: Option<i32>logged_in: Option<bool>os_platform: Option<u32>auth_type: Option<u32>gaming_device_type: Option<u32>first_seen: Option<TokenUsageEvent>last_seen: Option<TokenUsageEvent>os_type: Option<i32>authentication_type: Option<i32>effective_token_state: Option<i32>Implementations
Sourceimpl RefreshTokenDescription
impl RefreshTokenDescription
Sourcepub fn token_id(&self) -> u64
pub fn token_id(&self) -> u64
Returns the value of token_id, or the default value if token_id is unset.
Sourcepub fn token_description(&self) -> &str
pub fn token_description(&self) -> &str
Returns the value of token_description, or the default value if token_description is unset.
Sourcepub fn time_updated(&self) -> u32
pub fn time_updated(&self) -> u32
Returns the value of time_updated, or the default value if time_updated is unset.
Sourcepub fn platform_type(&self) -> EAuthTokenPlatformType
pub fn platform_type(&self) -> EAuthTokenPlatformType
Returns the enum value of platform_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_platform_type(&mut self, value: EAuthTokenPlatformType)
pub fn set_platform_type(&mut self, value: EAuthTokenPlatformType)
Sets platform_type to the provided enum value.
Sourcepub fn logged_in(&self) -> bool
pub fn logged_in(&self) -> bool
Returns the value of logged_in, or the default value if logged_in is unset.
Sourcepub fn os_platform(&self) -> u32
pub fn os_platform(&self) -> u32
Returns the value of os_platform, or the default value if os_platform is unset.
Sourcepub fn auth_type(&self) -> u32
pub fn auth_type(&self) -> u32
Returns the value of auth_type, or the default value if auth_type is unset.
Sourcepub fn gaming_device_type(&self) -> u32
pub fn gaming_device_type(&self) -> u32
Returns the value of gaming_device_type, or the default value if gaming_device_type is unset.
Sourcepub fn os_type(&self) -> i32
pub fn os_type(&self) -> i32
Returns the value of os_type, or the default value if os_type is unset.
Sourcepub fn authentication_type(&self) -> EAuthenticationType
pub fn authentication_type(&self) -> EAuthenticationType
Returns the enum value of authentication_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_authentication_type(&mut self, value: EAuthenticationType)
pub fn set_authentication_type(&mut self, value: EAuthenticationType)
Sets authentication_type to the provided enum value.
Sourcepub fn effective_token_state(&self) -> EAuthTokenState
pub fn effective_token_state(&self) -> EAuthTokenState
Returns the enum value of effective_token_state, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_effective_token_state(&mut self, value: EAuthTokenState)
pub fn set_effective_token_state(&mut self, value: EAuthTokenState)
Sets effective_token_state to the provided enum value.