pub struct CMsgAuthTicket {
pub estate: Option<u32>,
pub eresult: Option<u32>,
pub steamid: Option<u64>,
pub gameid: Option<u64>,
pub h_steam_pipe: Option<u32>,
pub ticket_crc: Option<u32>,
pub ticket: Option<Vec<u8>>,
pub server_secret: Option<Vec<u8>>,
pub ticket_type: Option<u32>,
}Expand description
Authentication ticket
Fields
estate: Option<u32>eresult: Option<u32>steamid: Option<u64>gameid: Option<u64>h_steam_pipe: Option<u32>ticket_crc: Option<u32>ticket: Option<Vec<u8>>server_secret: Option<Vec<u8>>ticket_type: Option<u32>Implementations
Sourceimpl CMsgAuthTicket
impl CMsgAuthTicket
Sourcepub fn estate(&self) -> u32
pub fn estate(&self) -> u32
Returns the value of estate, or the default value if estate is unset.
Sourcepub fn eresult(&self) -> u32
pub fn eresult(&self) -> u32
Returns the value of eresult, or the default value if eresult is unset.
Sourcepub fn steamid(&self) -> u64
pub fn steamid(&self) -> u64
Returns the value of steamid, or the default value if steamid is unset.
Sourcepub fn gameid(&self) -> u64
pub fn gameid(&self) -> u64
Returns the value of gameid, or the default value if gameid is unset.
Sourcepub fn h_steam_pipe(&self) -> u32
pub fn h_steam_pipe(&self) -> u32
Returns the value of h_steam_pipe, or the default value if h_steam_pipe is unset.
Sourcepub fn ticket_crc(&self) -> u32
pub fn ticket_crc(&self) -> u32
Returns the value of ticket_crc, or the default value if ticket_crc is unset.
Sourcepub fn ticket(&self) -> &[u8] ⓘ
pub fn ticket(&self) -> &[u8] ⓘ
Returns the value of ticket, or the default value if ticket is unset.
Sourcepub fn server_secret(&self) -> &[u8] ⓘ
pub fn server_secret(&self) -> &[u8] ⓘ
Returns the value of server_secret, or the default value if server_secret is unset.
Sourcepub fn ticket_type(&self) -> u32
pub fn ticket_type(&self) -> u32
Returns the value of ticket_type, or the default value if ticket_type is unset.