pub struct CFriendMessagesSendMessageRequest {
pub steamid: Option<u64>,
pub chat_entry_type: Option<i32>,
pub message: Option<String>,
pub contains_bbcode: Option<bool>,
pub echo_to_sender: Option<bool>,
pub low_priority: Option<bool>,
pub client_message_id: Option<String>,
}Expand description
Send message request
Fields
steamid: Option<u64>chat_entry_type: Option<i32>message: Option<String>contains_bbcode: Option<bool>echo_to_sender: Option<bool>low_priority: Option<bool>client_message_id: Option<String>Implementations
Sourceimpl CFriendMessagesSendMessageRequest
impl CFriendMessagesSendMessageRequest
Sourcepub fn steamid(&self) -> u64
pub fn steamid(&self) -> u64
Returns the value of steamid, or the default value if steamid is unset.
Sourcepub fn chat_entry_type(&self) -> i32
pub fn chat_entry_type(&self) -> i32
Returns the value of chat_entry_type, or the default value if chat_entry_type is unset.
Sourcepub fn message(&self) -> &str
pub fn message(&self) -> &str
Returns the value of message, or the default value if message is unset.
Sourcepub fn contains_bbcode(&self) -> bool
pub fn contains_bbcode(&self) -> bool
Returns the value of contains_bbcode, or the default value if contains_bbcode is unset.
Sourcepub fn echo_to_sender(&self) -> bool
pub fn echo_to_sender(&self) -> bool
Returns the value of echo_to_sender, or the default value if echo_to_sender is unset.
Sourcepub fn low_priority(&self) -> bool
pub fn low_priority(&self) -> bool
Returns the value of low_priority, or the default value if low_priority is unset.
Sourcepub fn client_message_id(&self) -> &str
pub fn client_message_id(&self) -> &str
Returns the value of client_message_id, or the default value if client_message_id is unset.