pub struct CMsgClientPlayingSessionState {
pub playing_blocked: Option<bool>,
pub playing_app: Option<u32>,
}Expand description
Playing session state - indicates if game playing is blocked by another session
Fields
playing_blocked: Option<bool>True if playing is blocked because this account is playing a game elsewhere
playing_app: Option<u32>The app ID currently being played (elsewhere if blocked, or by us if not blocked)
Implementations
Sourceimpl CMsgClientPlayingSessionState
impl CMsgClientPlayingSessionState
Sourcepub fn playing_blocked(&self) -> bool
pub fn playing_blocked(&self) -> bool
Returns the value of playing_blocked, or the default value if playing_blocked is unset.
Sourcepub fn playing_app(&self) -> u32
pub fn playing_app(&self) -> u32
Returns the value of playing_app, or the default value if playing_app is unset.