pub struct CUserAccountCreateFriendInviteTokenRequest {
pub invite_limit: Option<u32>,
pub invite_duration: Option<u32>,
pub invite_note: Option<String>,
}Expand description
Create friend invite token request (UserAccount.CreateFriendInviteToken#1)
Fields
invite_limit: Option<u32>Maximum number of times this invite can be used (0 = unlimited)
invite_duration: Option<u32>Duration in seconds that the invite is valid (0 = no expiry)
invite_note: Option<String>Optional note for this invite
Implementations
Sourceimpl CUserAccountCreateFriendInviteTokenRequest
impl CUserAccountCreateFriendInviteTokenRequest
Sourcepub fn invite_limit(&self) -> u32
pub fn invite_limit(&self) -> u32
Returns the value of invite_limit, or the default value if invite_limit is unset.
Sourcepub fn invite_duration(&self) -> u32
pub fn invite_duration(&self) -> u32
Returns the value of invite_duration, or the default value if invite_duration is unset.
Sourcepub fn invite_note(&self) -> &str
pub fn invite_note(&self) -> &str
Returns the value of invite_note, or the default value if invite_note is unset.