PublishedFileDetails

Struct PublishedFileDetails 

pub struct PublishedFileDetails {
Show 41 fields pub result: Option<u32>, pub publishedfileid: Option<u64>, pub creator: Option<u64>, pub creator_appid: Option<u32>, pub consumer_appid: Option<u32>, pub consumer_shortcutid: Option<u32>, pub filename: Option<String>, pub file_size: Option<u64>, pub preview_file_size: Option<u64>, pub file_url: Option<String>, pub preview_url: Option<String>, pub youtubevideoid: Option<String>, pub url: Option<String>, pub hcontent_file: Option<u64>, pub hcontent_preview: Option<u64>, pub title: Option<String>, pub file_description: Option<String>, pub short_description: Option<String>, pub time_created: Option<u32>, pub time_updated: Option<u32>, pub visibility: Option<u32>, pub flags: Option<u32>, pub workshop_file: Option<bool>, pub workshop_accepted: Option<bool>, pub banned: Option<bool>, pub ban_reason: Option<String>, pub banner: Option<u64>, pub can_be_deleted: Option<bool>, pub app_name: Option<String>, pub file_type: Option<u32>, pub can_subscribe: Option<bool>, pub subscriptions: Option<u32>, pub favorited: Option<u32>, pub followers: Option<u32>, pub lifetime_subscriptions: Option<u32>, pub lifetime_favorited: Option<u32>, pub lifetime_followers: Option<u32>, pub views: Option<u32>, pub tags: Vec<Tag>, pub kvtags: Vec<KvTag>, pub vote_data: Option<VoteData>,
}
Published file details

Fields

result: Option<u32>publishedfileid: Option<u64>creator: Option<u64>creator_appid: Option<u32>consumer_appid: Option<u32>consumer_shortcutid: Option<u32>filename: Option<String>file_size: Option<u64>preview_file_size: Option<u64>file_url: Option<String>preview_url: Option<String>youtubevideoid: Option<String>url: Option<String>hcontent_file: Option<u64>hcontent_preview: Option<u64>title: Option<String>file_description: Option<String>short_description: Option<String>time_created: Option<u32>time_updated: Option<u32>visibility: Option<u32>flags: Option<u32>workshop_file: Option<bool>workshop_accepted: Option<bool>banned: Option<bool>ban_reason: Option<String>banner: Option<u64>can_be_deleted: Option<bool>app_name: Option<String>file_type: Option<u32>can_subscribe: Option<bool>subscriptions: Option<u32>favorited: Option<u32>followers: Option<u32>lifetime_subscriptions: Option<u32>lifetime_favorited: Option<u32>lifetime_followers: Option<u32>views: Option<u32>tags: Vec<Tag>kvtags: Vec<KvTag>vote_data: Option<VoteData>

Implementations

Source

impl PublishedFileDetails

pub fn result(&self) -> u32

Returns the value of result, or the default value if result is unset.

pub fn publishedfileid(&self) -> u64

Returns the value of publishedfileid, or the default value if publishedfileid is unset.

pub fn creator(&self) -> u64

Returns the value of creator, or the default value if creator is unset.

pub fn creator_appid(&self) -> u32

Returns the value of creator_appid, or the default value if creator_appid is unset.

pub fn consumer_appid(&self) -> u32

Returns the value of consumer_appid, or the default value if consumer_appid is unset.

pub fn consumer_shortcutid(&self) -> u32

Returns the value of consumer_shortcutid, or the default value if consumer_shortcutid is unset.

pub fn filename(&self) -> &str

Returns the value of filename, or the default value if filename is unset.

pub fn file_size(&self) -> u64

Returns the value of file_size, or the default value if file_size is unset.

pub fn preview_file_size(&self) -> u64

Returns the value of preview_file_size, or the default value if preview_file_size is unset.

pub fn file_url(&self) -> &str

Returns the value of file_url, or the default value if file_url is unset.

pub fn preview_url(&self) -> &str

Returns the value of preview_url, or the default value if preview_url is unset.

pub fn youtubevideoid(&self) -> &str

Returns the value of youtubevideoid, or the default value if youtubevideoid is unset.

pub fn url(&self) -> &str

Returns the value of url, or the default value if url is unset.

pub fn hcontent_file(&self) -> u64

Returns the value of hcontent_file, or the default value if hcontent_file is unset.

pub fn hcontent_preview(&self) -> u64

Returns the value of hcontent_preview, or the default value if hcontent_preview is unset.

pub fn title(&self) -> &str

Returns the value of title, or the default value if title is unset.

pub fn file_description(&self) -> &str

Returns the value of file_description, or the default value if file_description is unset.

pub fn short_description(&self) -> &str

Returns the value of short_description, or the default value if short_description is unset.

pub fn time_created(&self) -> u32

Returns the value of time_created, or the default value if time_created is unset.

pub fn time_updated(&self) -> u32

Returns the value of time_updated, or the default value if time_updated is unset.

pub fn visibility(&self) -> u32

Returns the value of visibility, or the default value if visibility is unset.

pub fn flags(&self) -> u32

Returns the value of flags, or the default value if flags is unset.

pub fn workshop_file(&self) -> bool

Returns the value of workshop_file, or the default value if workshop_file is unset.

pub fn workshop_accepted(&self) -> bool

Returns the value of workshop_accepted, or the default value if workshop_accepted is unset.

pub fn banned(&self) -> bool

Returns the value of banned, or the default value if banned is unset.

pub fn ban_reason(&self) -> &str

Returns the value of ban_reason, or the default value if ban_reason is unset.

pub fn banner(&self) -> u64

Returns the value of banner, or the default value if banner is unset.

pub fn can_be_deleted(&self) -> bool

Returns the value of can_be_deleted, or the default value if can_be_deleted is unset.

pub fn app_name(&self) -> &str

Returns the value of app_name, or the default value if app_name is unset.

pub fn file_type(&self) -> u32

Returns the value of file_type, or the default value if file_type is unset.

pub fn can_subscribe(&self) -> bool

Returns the value of can_subscribe, or the default value if can_subscribe is unset.

pub fn subscriptions(&self) -> u32

Returns the value of subscriptions, or the default value if subscriptions is unset.

pub fn favorited(&self) -> u32

Returns the value of favorited, or the default value if favorited is unset.

pub fn followers(&self) -> u32

Returns the value of followers, or the default value if followers is unset.

pub fn lifetime_subscriptions(&self) -> u32

Returns the value of lifetime_subscriptions, or the default value if lifetime_subscriptions is unset.

pub fn lifetime_favorited(&self) -> u32

Returns the value of lifetime_favorited, or the default value if lifetime_favorited is unset.

pub fn lifetime_followers(&self) -> u32

Returns the value of lifetime_followers, or the default value if lifetime_followers is unset.

pub fn views(&self) -> u32

Returns the value of views, or the default value if views is unset.