pub struct PublishedFileDetails {Show 41 fields
pub result: Option<u32>,
pub publishedfileid: Option<u64>,
pub creator: Option<u64>,
pub creator_appid: Option<u32>,
pub consumer_appid: Option<u32>,
pub consumer_shortcutid: Option<u32>,
pub filename: Option<String>,
pub file_size: Option<u64>,
pub preview_file_size: Option<u64>,
pub file_url: Option<String>,
pub preview_url: Option<String>,
pub youtubevideoid: Option<String>,
pub url: Option<String>,
pub hcontent_file: Option<u64>,
pub hcontent_preview: Option<u64>,
pub title: Option<String>,
pub file_description: Option<String>,
pub short_description: Option<String>,
pub time_created: Option<u32>,
pub time_updated: Option<u32>,
pub visibility: Option<u32>,
pub flags: Option<u32>,
pub workshop_file: Option<bool>,
pub workshop_accepted: Option<bool>,
pub banned: Option<bool>,
pub ban_reason: Option<String>,
pub banner: Option<u64>,
pub can_be_deleted: Option<bool>,
pub app_name: Option<String>,
pub file_type: Option<u32>,
pub can_subscribe: Option<bool>,
pub subscriptions: Option<u32>,
pub favorited: Option<u32>,
pub followers: Option<u32>,
pub lifetime_subscriptions: Option<u32>,
pub lifetime_favorited: Option<u32>,
pub lifetime_followers: Option<u32>,
pub views: Option<u32>,
pub tags: Vec<Tag>,
pub kvtags: Vec<KvTag>,
pub vote_data: Option<VoteData>,
}Expand description
Published file details
Fields
result: Option<u32>publishedfileid: Option<u64>creator: Option<u64>creator_appid: Option<u32>consumer_appid: Option<u32>consumer_shortcutid: Option<u32>filename: Option<String>file_size: Option<u64>preview_file_size: Option<u64>file_url: Option<String>preview_url: Option<String>youtubevideoid: Option<String>url: Option<String>hcontent_file: Option<u64>hcontent_preview: Option<u64>title: Option<String>file_description: Option<String>short_description: Option<String>time_created: Option<u32>time_updated: Option<u32>visibility: Option<u32>flags: Option<u32>workshop_file: Option<bool>workshop_accepted: Option<bool>banned: Option<bool>ban_reason: Option<String>can_be_deleted: Option<bool>app_name: Option<String>file_type: Option<u32>can_subscribe: Option<bool>subscriptions: Option<u32>favorited: Option<u32>followers: Option<u32>lifetime_subscriptions: Option<u32>lifetime_favorited: Option<u32>lifetime_followers: Option<u32>views: Option<u32>vote_data: Option<VoteData>Implementations
Sourceimpl PublishedFileDetails
impl PublishedFileDetails
Sourcepub fn result(&self) -> u32
pub fn result(&self) -> u32
Returns the value of result, or the default value if result is unset.
Sourcepub fn publishedfileid(&self) -> u64
pub fn publishedfileid(&self) -> u64
Returns the value of publishedfileid, or the default value if publishedfileid is unset.
Sourcepub fn creator(&self) -> u64
pub fn creator(&self) -> u64
Returns the value of creator, or the default value if creator is unset.
Sourcepub fn creator_appid(&self) -> u32
pub fn creator_appid(&self) -> u32
Returns the value of creator_appid, or the default value if creator_appid is unset.
Sourcepub fn consumer_appid(&self) -> u32
pub fn consumer_appid(&self) -> u32
Returns the value of consumer_appid, or the default value if consumer_appid is unset.
Sourcepub fn consumer_shortcutid(&self) -> u32
pub fn consumer_shortcutid(&self) -> u32
Returns the value of consumer_shortcutid, or the default value if consumer_shortcutid is unset.
Sourcepub fn filename(&self) -> &str
pub fn filename(&self) -> &str
Returns the value of filename, or the default value if filename is unset.
Sourcepub fn file_size(&self) -> u64
pub fn file_size(&self) -> u64
Returns the value of file_size, or the default value if file_size is unset.
Sourcepub fn preview_file_size(&self) -> u64
pub fn preview_file_size(&self) -> u64
Returns the value of preview_file_size, or the default value if preview_file_size is unset.
Sourcepub fn file_url(&self) -> &str
pub fn file_url(&self) -> &str
Returns the value of file_url, or the default value if file_url is unset.
Sourcepub fn preview_url(&self) -> &str
pub fn preview_url(&self) -> &str
Returns the value of preview_url, or the default value if preview_url is unset.
Sourcepub fn youtubevideoid(&self) -> &str
pub fn youtubevideoid(&self) -> &str
Returns the value of youtubevideoid, or the default value if youtubevideoid is unset.
Sourcepub fn hcontent_file(&self) -> u64
pub fn hcontent_file(&self) -> u64
Returns the value of hcontent_file, or the default value if hcontent_file is unset.
Sourcepub fn hcontent_preview(&self) -> u64
pub fn hcontent_preview(&self) -> u64
Returns the value of hcontent_preview, or the default value if hcontent_preview is unset.
Sourcepub fn title(&self) -> &str
pub fn title(&self) -> &str
Returns the value of title, or the default value if title is unset.
Sourcepub fn file_description(&self) -> &str
pub fn file_description(&self) -> &str
Returns the value of file_description, or the default value if file_description is unset.
Sourcepub fn short_description(&self) -> &str
pub fn short_description(&self) -> &str
Returns the value of short_description, or the default value if short_description is unset.
Sourcepub fn time_created(&self) -> u32
pub fn time_created(&self) -> u32
Returns the value of time_created, or the default value if time_created is unset.
Sourcepub fn time_updated(&self) -> u32
pub fn time_updated(&self) -> u32
Returns the value of time_updated, or the default value if time_updated is unset.
Sourcepub fn visibility(&self) -> u32
pub fn visibility(&self) -> u32
Returns the value of visibility, or the default value if visibility is unset.
Sourcepub fn workshop_file(&self) -> bool
pub fn workshop_file(&self) -> bool
Returns the value of workshop_file, or the default value if workshop_file is unset.
Sourcepub fn workshop_accepted(&self) -> bool
pub fn workshop_accepted(&self) -> bool
Returns the value of workshop_accepted, or the default value if workshop_accepted is unset.
Sourcepub fn banned(&self) -> bool
pub fn banned(&self) -> bool
Returns the value of banned, or the default value if banned is unset.
Sourcepub fn ban_reason(&self) -> &str
pub fn ban_reason(&self) -> &str
Returns the value of ban_reason, or the default value if ban_reason is unset.
Returns the value of banner, or the default value if banner is unset.
Sourcepub fn can_be_deleted(&self) -> bool
pub fn can_be_deleted(&self) -> bool
Returns the value of can_be_deleted, or the default value if can_be_deleted is unset.
Sourcepub fn app_name(&self) -> &str
pub fn app_name(&self) -> &str
Returns the value of app_name, or the default value if app_name is unset.
Sourcepub fn file_type(&self) -> u32
pub fn file_type(&self) -> u32
Returns the value of file_type, or the default value if file_type is unset.
Sourcepub fn can_subscribe(&self) -> bool
pub fn can_subscribe(&self) -> bool
Returns the value of can_subscribe, or the default value if can_subscribe is unset.
Sourcepub fn subscriptions(&self) -> u32
pub fn subscriptions(&self) -> u32
Returns the value of subscriptions, or the default value if subscriptions is unset.
Sourcepub fn favorited(&self) -> u32
pub fn favorited(&self) -> u32
Returns the value of favorited, or the default value if favorited is unset.
Sourcepub fn followers(&self) -> u32
pub fn followers(&self) -> u32
Returns the value of followers, or the default value if followers is unset.
Sourcepub fn lifetime_subscriptions(&self) -> u32
pub fn lifetime_subscriptions(&self) -> u32
Returns the value of lifetime_subscriptions, or the default value if lifetime_subscriptions is unset.
Sourcepub fn lifetime_favorited(&self) -> u32
pub fn lifetime_favorited(&self) -> u32
Returns the value of lifetime_favorited, or the default value if lifetime_favorited is unset.
Sourcepub fn lifetime_followers(&self) -> u32
pub fn lifetime_followers(&self) -> u32
Returns the value of lifetime_followers, or the default value if lifetime_followers is unset.